==> persisted_bloc_stream-4.2.6.tar.gz: test/persisted_bloc_stream_test.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:dartz/dartz.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:persisted_bloc_stream/persisted_bloc_stream.dart';
import 'package:persisted_bloc_stream/storage.dart';

class MockStorage extends Mock implements Storage {}

class MyPersistedActions {
  static Stream<int> increment(int i, MyPersistedBloc bloc) async* {
    yield i + 1;
  }

  static Stream<int> decrement(int i, MyPersistedBloc bloc) async* {
    yield i - 1;
  }
}

class MyPersistedBloc extends PersistedBlocStream<int> {
  MyPersistedBloc() : super(0);

  @override
  int fromJson(dynamic json) => json;

  @override
  dynamic toJson(int value) => value;
}

void main() {
  MockStorage storage;

  setUp(() {
    storage = MockStorage();
    PersistedBlocStream.storage = storage;
  });

  test('should call storage.write for every new state', () async {
    when(storage.read(any)).thenReturn(none());
    when(storage.write("MyPersistedBloc", any))
        .thenAnswer((_) => Future.value(true));

    final completer = Completer<bool>();

    final bloc = MyPersistedBloc();
    bloc.add(MyPersistedActions.increment);
    bloc.add(MyPersistedActions.decrement);
    bloc.add((s, b) async* {
      completer.complete(true);
    });

    expect(await completer.future, isTrue);
    verify(storage.write('MyPersistedBloc', jsonEncode(1))).called(1);
    verify(storage.write('MyPersistedBloc', jsonEncode(0))).called(1);
  });

  test('should initialize with existing state', () async {
    when(storage.read(any)).thenReturn(some(jsonEncode(7)));
    final bloc = MyPersistedBloc();
    expect(bloc.value, 7);
  });
}

==> persisted_bloc_stream-4.3.3.tar.gz: test/persisted_bloc_stream_test.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:bloc_stream/bloc_stream.dart';
import 'package:dartz/dartz.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:persisted_bloc_stream/persisted_bloc_stream.dart';
import 'package:persisted_bloc_stream/storage.dart';

class MockStorage extends Mock implements Storage {}

class MyPersistedActions {
  static final Action<MyPersistedBloc, int> increment =
      (bloc, add) async => add(bloc.value + 1);

  static final Action<MyPersistedBloc, int> decrement =
      (bloc, add) async => add(bloc.value - 1);
}

class MyPersistedBloc extends PersistedBlocStream<int> {
  MyPersistedBloc() : super(0);

  @override
  int fromJson(dynamic json) => json;

  @override
  dynamic toJson(int value) => value;
}

void main() {
  MockStorage storage;

  setUp(() {
    storage = MockStorage();
    PersistedBlocStream.storage = storage;
  });

  test('should call storage.write for every new state', () async {
    when(storage.read(any)).thenReturn(none());
    when(storage.write('MyPersistedBloc', any))
        .thenAnswer((_) => Future.value(true));

    final completer = Completer<bool>();

    final bloc = MyPersistedBloc();
    bloc.add(MyPersistedActions.increment);
    bloc.add(MyPersistedActions.decrement);
    bloc.add((b, add) async => completer.complete(true));

    expect(await completer.future, isTrue);
    verify(storage.write('MyPersistedBloc', jsonEncode(1))).called(1);
    verify(storage.write('MyPersistedBloc', jsonEncode(0))).called(1);
  });

  test('should initialize with existing state', () async {
    when(storage.read(any)).thenReturn(some(jsonEncode(7)));
    final bloc = MyPersistedBloc();
    expect(bloc.value, 7);
  });
}
